@@ -16,13 +16,10 @@ how to call these functions.
     :toctree: generated/
 
     get_dd_wind_field
-    get_dd_wind_field_nested
     get_bca
     DDParameters
-
 """
 
 from .wind_retrieve import get_dd_wind_field
 from .wind_retrieve import get_bca
 from .wind_retrieve import DDParameters
-from .nesting import get_dd_wind_field_nested
